==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/delegatednetwork/kotlin/ControllerDetails.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.delegatednetwork.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [ControllerDetails].
 */
@PulumiTagMarker
public class ControllerDetailsResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ControllerDetailsArgs = ControllerDetailsArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ControllerDetailsArgsBuilder.() -> Unit) {
        val builder = ControllerDetailsArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ControllerDetails {
        val builtJavaResource =
            com.pulumi.azurenative.delegatednetwork.ControllerDetails(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ControllerDetails(builtJavaResource)
    }
}

/**
 * Represents an instance of a DNC controller.
 * Azure REST API version: 2021-03-15. Prior API version in Azure Native 1.x: 2021-03-15.
 * Other available API versions: 2023-05-18-preview, 2023-06-27-preview.
 * ## Example Usage
 * ### Create controller
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var controllerDetails = new AzureNative.DelegatedNetwork.ControllerDetails("controllerDetails", new()
 *     {
 *         Location = "West US",
 *         ResourceGroupName = "TestRG",
 *         ResourceName = "testcontroller",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/delegatednetwork/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := delegatednetwork.NewControllerDetails(ctx, "controllerDetails", &delegatednetwork.ControllerDetailsArgs{
 * 			Location:          pulumi.String("West US"),
 * 			ResourceGroupName: pulumi.String("TestRG"),
 * 			ResourceName:      pulumi.String("testcontroller"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.delegatednetwork.ControllerDetails;
 * import com.pulumi.azurenative.delegatednetwork.ControllerDetailsArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var controllerDetails = new ControllerDetails("controllerDetails", ControllerDetailsArgs.builder()
 *             .location("West US")
 *             .resourceGroupName("TestRG")
 *             .resourceName("testcontroller")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:delegatednetwork:ControllerDetails testcontroller /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DelegatedNetwork/controller/{resourceName}
 * ```
 */
public class ControllerDetails internal constructor(
    override val javaResource: com.pulumi.azurenative.delegatednetwork.ControllerDetails,
) : KotlinCustomResource(javaResource, ControllerDetailsMapper) {
    /**
     * dnc application id should be used by customer to authenticate with dnc gateway.
     */
    public val dncAppId: Output<String>
        get() = javaResource.dncAppId().applyValue({ args0 -> args0 })

    /**
     * dnc endpoint url that customers can use to connect to
     */
    public val dncEndpoint: Output<String>
        get() = javaResource.dncEndpoint().applyValue({ args0 -> args0 })

    /**
     * tenant id of dnc application id
     */
    public val dncTenantId: Output<String>
        get() = javaResource.dncTenantId().applyValue({ args0 -> args0 })

    /**
     * Location of the resource.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The current state of dnc controller resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource guid.
     */
    public val resourceGuid: Output<String>
        get() = javaResource.resourceGuid().applyValue({ args0 -> args0 })

    /**
     * The resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ControllerDetailsMapper : ResourceMapper<ControllerDetails> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.delegatednetwork.ControllerDetails::class == javaResource::class

    override fun map(javaResource: Resource): ControllerDetails = ControllerDetails(
        javaResource as
            com.pulumi.azurenative.delegatednetwork.ControllerDetails,
    )
}

/**
 * @see [ControllerDetails].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ControllerDetails].
 */
public suspend fun controllerDetails(
    name: String,
    block: suspend ControllerDetailsResourceBuilder.() -> Unit,
): ControllerDetails {
    val builder = ControllerDetailsResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ControllerDetails].
 * @param name The _unique_ name of the resulting resource.
 */
public fun controllerDetails(name: String): ControllerDetails {
    val builder = ControllerDetailsResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/delegatednetwork/kotlin/ControllerDetails.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.delegatednetwork.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [ControllerDetails].
 */
@PulumiTagMarker
public class ControllerDetailsResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ControllerDetailsArgs = ControllerDetailsArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ControllerDetailsArgsBuilder.() -> Unit) {
        val builder = ControllerDetailsArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ControllerDetails {
        val builtJavaResource =
            com.pulumi.azurenative.delegatednetwork.ControllerDetails(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ControllerDetails(builtJavaResource)
    }
}

/**
 * Represents an instance of a DNC controller.
 * Azure REST API version: 2021-03-15. Prior API version in Azure Native 1.x: 2021-03-15.
 * Other available API versions: 2023-05-18-preview, 2023-06-27-preview.
 * ## Example Usage
 * ### Create controller
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var controllerDetails = new AzureNative.DelegatedNetwork.ControllerDetails("controllerDetails", new()
 *     {
 *         Location = "West US",
 *         ResourceGroupName = "TestRG",
 *         ResourceName = "testcontroller",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/delegatednetwork/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := delegatednetwork.NewControllerDetails(ctx, "controllerDetails", &delegatednetwork.ControllerDetailsArgs{
 * 			Location:          pulumi.String("West US"),
 * 			ResourceGroupName: pulumi.String("TestRG"),
 * 			ResourceName:      pulumi.String("testcontroller"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.delegatednetwork.ControllerDetails;
 * import com.pulumi.azurenative.delegatednetwork.ControllerDetailsArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var controllerDetails = new ControllerDetails("controllerDetails", ControllerDetailsArgs.builder()
 *             .location("West US")
 *             .resourceGroupName("TestRG")
 *             .resourceName("testcontroller")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:delegatednetwork:ControllerDetails testcontroller /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DelegatedNetwork/controller/{resourceName}
 * ```
 */
public class ControllerDetails internal constructor(
    override val javaResource: com.pulumi.azurenative.delegatednetwork.ControllerDetails,
) : KotlinCustomResource(javaResource, ControllerDetailsMapper) {
    /**
     * dnc application id should be used by customer to authenticate with dnc gateway.
     */
    public val dncAppId: Output<String>
        get() = javaResource.dncAppId().applyValue({ args0 -> args0 })

    /**
     * dnc endpoint url that customers can use to connect to
     */
    public val dncEndpoint: Output<String>
        get() = javaResource.dncEndpoint().applyValue({ args0 -> args0 })

    /**
     * tenant id of dnc application id
     */
    public val dncTenantId: Output<String>
        get() = javaResource.dncTenantId().applyValue({ args0 -> args0 })

    /**
     * Location of the resource.
     */
    public val location: Output<String>?
        get() = javaResource.location().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The current state of dnc controller resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource guid.
     */
    public val resourceGuid: Output<String>
        get() = javaResource.resourceGuid().applyValue({ args0 -> args0 })

    /**
     * The resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ControllerDetailsMapper : ResourceMapper<ControllerDetails> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.delegatednetwork.ControllerDetails::class == javaResource::class

    override fun map(javaResource: Resource): ControllerDetails = ControllerDetails(
        javaResource as
            com.pulumi.azurenative.delegatednetwork.ControllerDetails,
    )
}

/**
 * @see [ControllerDetails].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ControllerDetails].
 */
public suspend fun controllerDetails(
    name: String,
    block: suspend ControllerDetailsResourceBuilder.() -> Unit,
): ControllerDetails {
    val builder = ControllerDetailsResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ControllerDetails].
 * @param name The _unique_ name of the resulting resource.
 */
public fun controllerDetails(name: String): ControllerDetails {
    val builder = ControllerDetailsResourceBuilder()
    builder.name(name)
    return builder.build()
}
